# Test results and reports

As soon as you start [sending test results](../sending-data-to-launchable/) to Launchable using the Launchable CLI, you can view **test reports** in the Launchable webapp. Launchable provides a richer view into test results, helping developers triage failures and fix them more quickly.

![](<../.gitbook/assets/2022-08-03 Test session details - with content.png>)

For quick access to test results, the Launchable CLI prints out a link to this page every time you record test results:

![](<../.gitbook/assets/Link to results.png>)

In addition, the **Test Sessions** page shows all of your sessions in one place for easy navigation. No more digging around build logs:

![](<../.gitbook/assets/2022-06 Test Sessions.png>)
